@@ -89,8 +89,13 @@ class NoteSet(Cached):
     @property
     def rootless(self): return NoteSet(self.notes)
 
+    def transpose_to(self, note: Note) -> NoteSet:
+        if self.root is None:
+            raise ValueError('noteset should have root to be transposed')
+        return NoteSet.from_intervals(note, self.intervals)
+
     @classmethod
-    def from_name(cls, root: str | Note, name: str):
+    def from_name(cls, root: str | Note, name: str) -> NoteSet:
         if isinstance(root, str):
             root = Note(root)
         notes = frozenset(root + interval for interval in cls.name_to_intervals[name]) | {root}
